==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/it.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etichetta di sistema %1$s aggiunta dal sistema",
    "Added system tag {systemtag}" : "Aggiunta l'etichetta di sistema {systemtag}",
    "Added system tag %1$s" : "Aggiunta l'etichetta di sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha aggiunto l'etichetta di sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etichetta di sistema %1$s rimossa dal sistema",
    "Removed system tag {systemtag}" : "Etichetta di sistema {systemtag} rimossa",
    "Removed system tag %1$s" : "Etichetta di sistema %1$s rimossa",
    "%1$s removed system tag %2$s" : "%1$s ha rimosso l'etichetta di sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha rimosso l'etichetta di sistema {systemtag}",
    "You created system tag %1$s" : "Hai creato l'etichetta di sistema %1$s",
    "You created system tag {systemtag}" : "Hai creato l'etichetta di sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creato l'etichetta di sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creato l'etichetta di sistema {systemtag}",
    "You deleted system tag %1$s" : "Hai eliminato l'etichetta di sistema %1$s",
    "You deleted system tag {systemtag}" : "Hai eliminato l'etichetta di sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha eliminato l'etichetta di sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha eliminato l'etichetta di sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Hai aggiornato l'etichetta di sistema %2$s in %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Hai aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha aggiornato l'etichetta di sistema %3$s in %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'etichetta di sistema %2$s è stata aggiunta a %1$s dal sistema",
    "System tag {systemtag} was added to {file} by the system" : "L'etichetta di sistema {systemtag} è stata aggiunta a {file} dal sistema",
    "You added system tag %2$s to %1$s" : "Hai aggiunto l'etichetta di sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Hai aggiunto l'etichetta di sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha aggiunto l'etichetta di sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'etichetta di sistema %2$s è stata rimossa da %1$s dal sistema",
    "System tag {systemtag} was removed from {file} by the system" : "L'etichetta di sistema {systemtag} è stata rimossa da {file} dal sistema",
    "You removed system tag %2$s from %1$s" : "Hai rimosso l'etichetta di sistema %2$s da %1$s",
    "You removed system tag {systemtag} from {file}" : "Hai rimosso l'etichetta di sistema {systemtag} da {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha rimosso l'etichetta di sistema %3$s da %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha rimosso l'etichetta di sistema {systemtag} da {file}",
    "%s (restricted)" : "%s (limitato)",
    "%s (invisible)" : "%s (invisibile)",
    "<strong>System tags</strong> for a file have been modified" : "Le <strong>etichette di sistema</strong> per un file sono state modificate",
    "Files" : "File",
    "Tags" : "Etichette",
    "All tagged %s …" : "Tutti etichettati %s …",
    "tagged %s" : "etichettato %s",
    "Collaborative tags" : "Etichette collaborative",
    "Collaborative tagging functionality which shares tags among people." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra le persone.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra le persone. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
    "Public" : "Pubblico",
    "Restricted" : "Limitato",
    "Invisible" : "invisibile",
    "Created tag" : "Etichetta creata",
    "Failed to create tag" : "Creazione etichetta fallita",
    "Updated tag" : "Etichetta aggiornata",
    "Failed to update tag" : "Aggiornamento dell'etichetta fallito",
    "Deleted tag" : "Etichetta eliminata",
    "Failed to delete tag" : "Eliminazione etichetta fallita",
    "Create or edit tags" : "Crea o modifica etichette",
    "Search for a tag to edit" : "Cerca un'etichetta da modificare",
    "Collaborative tags …" : "Etichette collaborative …",
    "No tags to select" : "Nessuna etichetta da selezionare",
    "Tag name" : "Nome etichetta",
    "Tag level" : "Livello etichetta",
    "Create" : "Crea",
    "Update" : "Aggiorna",
    "Delete" : "Elimina",
    "Reset" : "Ripristina",
    "Loading …" : "Caricamento…",
    "{displayName} (hidden)" : "{displayName} (nascosto)",
    "{displayName} (restricted)" : "{displayName} (limitato)",
    "Failed to apply tags changes" : "Impossibile applicare le modifiche ai tag",
    "Manage tags" : "Gestisci etichette",
    "Applying tags changes…" : "Applico le modifiche ai tag...",
    "Search or create tag" : "Cerca o crea tag",
    "Create new tag" : "Crea un nuovo tag",
    "Cancel" : "Annulla",
    "Apply" : "Applica",
    "Failed to load tags" : "Caricamento etichette non riuscito",
    "Failed to load selected tags" : "Caricamento etichette selezionate fallito",
    "Failed to select tag" : "Selezione etichetta fallita",
    "Loading collaborative tags …" : "Caricamento etichette collaborative …",
    "Search or create collaborative tags" : "Cerca o crea etichette collaborative",
    "No tags to select, type to create a new tag" : "Nessuna etichetta da selezionare, digita per crearne una nuova",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per uso interno, poiché gli utenti non possono vederle o assegnarle.",
    "Assigned collaborative tags" : "Etichette collaborative assegnate",
    "Open in Files" : "Apri in File",
    "List of tags and their associated files and folders." : "Lista di etichette e dei loro file e cartelle associati.",
    "No tags found" : "Nessuna etichetta trovata",
    "Tags you have created will show up here." : "Le etichette che hai creato saranno mostrate qui.",
    "Failed to load tag" : "Impossibile caricare i tag",
    "Failed to load last used tags" : "Caricamento ultime etichette usate fallito",
    "Missing \"Content-Location\" header" : "Intestazione \"Content-Location\" mancante",
    "A tag with the same name already exists" : "Esiste già un tag con lo stesso nome",
    "Failed to load tags for file" : "Caricamento delle etichette per il file fallito",
    "Failed to set tag for file" : "Impostazione dell'etichetta per il file fallita",
    "Failed to delete tag for file" : "Eliminazione dell'etichetta per il file fallita",
    "File tags modification canceled" : "Modifiche ai tag dei file annullate",
    "Select or create tags to apply to all selected files" : "Seleziona o crea i tag da applicare a tutti i file selezionati",
    "Apply changes" : "Applica modifiche"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/it.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etichetta di sistema %1$s aggiunta dal sistema",
    "Added system tag {systemtag}" : "Aggiunta l'etichetta di sistema {systemtag}",
    "Added system tag %1$s" : "Aggiunta l'etichetta di sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha aggiunto l'etichetta di sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etichetta di sistema %1$s rimossa dal sistema",
    "Removed system tag {systemtag}" : "Etichetta di sistema {systemtag} rimossa",
    "Removed system tag %1$s" : "Etichetta di sistema %1$s rimossa",
    "%1$s removed system tag %2$s" : "%1$s ha rimosso l'etichetta di sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha rimosso l'etichetta di sistema {systemtag}",
    "You created system tag %1$s" : "Hai creato l'etichetta di sistema %1$s",
    "You created system tag {systemtag}" : "Hai creato l'etichetta di sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creato l'etichetta di sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creato l'etichetta di sistema {systemtag}",
    "You deleted system tag %1$s" : "Hai eliminato l'etichetta di sistema %1$s",
    "You deleted system tag {systemtag}" : "Hai eliminato l'etichetta di sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha eliminato l'etichetta di sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha eliminato l'etichetta di sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Hai aggiornato l'etichetta di sistema %2$s in %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Hai aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha aggiornato l'etichetta di sistema %3$s in %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'etichetta di sistema %2$s è stata aggiunta a %1$s dal sistema",
    "System tag {systemtag} was added to {file} by the system" : "L'etichetta di sistema {systemtag} è stata aggiunta a {file} dal sistema",
    "You added system tag %2$s to %1$s" : "Hai aggiunto l'etichetta di sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Hai aggiunto l'etichetta di sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha aggiunto l'etichetta di sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'etichetta di sistema %2$s è stata rimossa da %1$s dal sistema",
    "System tag {systemtag} was removed from {file} by the system" : "L'etichetta di sistema {systemtag} è stata rimossa da {file} dal sistema",
    "You removed system tag %2$s from %1$s" : "Hai rimosso l'etichetta di sistema %2$s da %1$s",
    "You removed system tag {systemtag} from {file}" : "Hai rimosso l'etichetta di sistema {systemtag} da {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha rimosso l'etichetta di sistema %3$s da %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha rimosso l'etichetta di sistema {systemtag} da {file}",
    "%s (restricted)" : "%s (limitato)",
    "%s (invisible)" : "%s (invisibile)",
    "<strong>System tags</strong> for a file have been modified" : "Le <strong>etichette di sistema</strong> per un file sono state modificate",
    "Files" : "File",
    "Tags" : "Etichette",
    "All tagged %s …" : "Tutti etichettati %s …",
    "tagged %s" : "etichettato %s",
    "Collaborative tags" : "Etichette collaborative",
    "Collaborative tagging functionality which shares tags among people." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra le persone.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra le persone. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
    "Public" : "Pubblico",
    "Restricted" : "Limitato",
    "Invisible" : "invisibile",
    "Created tag" : "Etichetta creata",
    "Failed to create tag" : "Creazione etichetta fallita",
    "Updated tag" : "Etichetta aggiornata",
    "Failed to update tag" : "Aggiornamento dell'etichetta fallito",
    "Deleted tag" : "Etichetta eliminata",
    "Failed to delete tag" : "Eliminazione etichetta fallita",
    "Create or edit tags" : "Crea o modifica etichette",
    "Search for a tag to edit" : "Cerca un'etichetta da modificare",
    "Collaborative tags …" : "Etichette collaborative …",
    "No tags to select" : "Nessuna etichetta da selezionare",
    "Tag name" : "Nome etichetta",
    "Tag level" : "Livello etichetta",
    "Create" : "Crea",
    "Update" : "Aggiorna",
    "Delete" : "Elimina",
    "Reset" : "Ripristina",
    "Loading …" : "Caricamento in corso...",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} verrà impostato e {tag2} verrà rimosso da 1 files.","{tag1} verrà impostato e {tag2} verrà rimosso da {count} files.","{tag1} verrà impostato e {tag2} verrà rimosso da {count} files."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} verrà impostato a 1 files.","{tag} verrà impostato a {count} files.","{tag} verrà impostato a {count} files."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} verrà rimosso da 1 file.","{tag} verrà rimosso da {count} files.","{tag} verrà rimosso da {count} files."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} verranno impostati a 1 file.","{tags} e {lastTag} verranno impostati a {count} files.","{tags} e {lastTag} verranno impostati a {count} files."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} e {lastTag} verranno rimossi da 1 file.","{tags} e {lastTag} verranno rimossi da {count} files.","{tags} e {lastTag} verranno rimossi da {count} files."],
    "{displayName} (hidden)" : "{displayName} (nascosto)",
    "{displayName} (restricted)" : "{displayName} (limitato)",
    "Only admins can create new tags" : "Solo gli amministratori possono creare nuove etichette",
    "Failed to apply tags changes" : "Impossibile applicare le modifiche alle etichette",
    "Manage tags" : "Gestisci etichette",
    "Applying tags changes…" : "Applico le modifiche alle etichette...",
    "Search or create tag" : "Cerca o crea etichetta",
    "Search tag" : "Cerca etichetta",
    "Change tag color" : "Cambia colore etichetta",
    "Create new tag" : "Crea una nuova etichetta",
    "Choose tags for the selected files" : "Scegli le etichette per i file selezionati",
    "Cancel" : "Annulla",
    "Apply" : "Applica",
    "Failed to load selected tags" : "Caricamento etichette selezionate fallito",
    "Failed to load tags" : "Caricamento etichette non riuscito",
    "Failed to select tag" : "Selezione etichetta fallita",
    "System admin disabled tag creation. You can only use existing ones." : "L'amministratore di sistema ha disabilitato la creazione di etichette. È possibile utilizzare solo quelle esistenti.",
    "Loading collaborative tags …" : "Caricamento etichette collaborative …",
    "Search or create collaborative tags" : "Cerca o crea etichette collaborative",
    "No tags to select, type to create a new tag" : "Nessuna etichetta da selezionare, digita per crearne una nuova",
    "Unable to update setting" : "Impossibile aggiornare le impostazioni",
    "System tag creation is now restricted to administrators" : "La creazione delle etichette di sistema è ora limitata agli amministratori.",
    "System tag creation is now allowed for everybody" : "La creazione delle etichette di sistema è ora consentita a tutti",
    "System tag management" : "Gestione delle etichette di sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Se abilitato, solo gli amministratori possono creare e modificare le etichette. Gli account possono comunque assegnarli e rimuoverli dai file.",
    "Restrict tag creation and editing to administrators" : "Limitare la creazione e la modifica delle etichette agli amministratori",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per uso interno, poiché gli utenti non possono vederle o assegnarle.",
    "Assigned collaborative tags" : "Etichette collaborative assegnate",
    "Open in Files" : "Apri in File",
    "List of tags and their associated files and folders." : "Lista di etichette e dei loro file e cartelle associati.",
    "No tags found" : "Nessuna etichetta trovata",
    "Tags you have created will show up here." : "Le etichette che hai creato saranno mostrate qui.",
    "Failed to load tag" : "Impossibile caricare le etichette",
    "Failed to load last used tags" : "Caricamento ultime etichette usate fallito",
    "Missing \"Content-Location\" header" : "Intestazione \"Content-Location\" mancante",
    "A tag with the same name already exists" : "Esiste già un'etichetta con lo stesso nome",
    "Failed to load tags for file" : "Caricamento delle etichette per il file fallito",
    "Failed to set tag for file" : "Impostazione dell'etichetta per il file fallita",
    "Failed to delete tag for file" : "Eliminazione dell'etichetta per il file fallita",
    "Collaborative tags …" : "Etichette collaborative …",
    "Loading …" : "Caricamento…",
    "File tags modification canceled" : "Modifiche alle etichette dei file annullate",
    "Select or create tags to apply to all selected files" : "Seleziona o crea le etichette da applicare a tutti i file selezionati",
    "Select tags to apply to all selected files" : "Seleziona le etichette da applicare a tutti i file selezionati",
    "Apply changes" : "Applica modifiche",
    "Loading collaborative tags …" : "Caricamento etichette collaborative …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
